#!/usr/bin/python
# -*- coding: Latin-1 -*-
#
# SMM Share and Money Management
# Copyright (c) 2007-2010 Carsten Grohmann
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 2 of the
# License.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.

## \file smmshell.py
#
# \short A simple customised Python shell to act in
#
# \author Carsten Grohmann <mail (at) carstengrohmann (dot) de>
#
# \par License:
# GPL version 2.0

# import general python modules
import code
import datetime
import decimal
import logging
import os.path
import sys
import zipfile
try:
    import readline
    import rlcompleter
except ImportError:
    print "Module readline not available."

# check for smm zip file
if os.path.exists("./smm.zip") and zipfile.is_zipfile("./smm.zip"):
    sys.path.insert(0, './smm.zip')

# import gettext and initiate dummy instance
import gettext
gettext.NullTranslations().install()

# import project specific modules
import smm


## \brief Initialise the main components and open a Python shell to act in
def run_shell():
    # log all to the Console
    dfl_formatter = logging.Formatter('%(levelname)-8s: %(message)s')
    logger = logging.getLogger()

    console = logging.StreamHandler()
    console.setLevel(logging.INFO)
    console.setFormatter(dfl_formatter)
    logger.addHandler(console)
    logger.setLevel(logging.NOTSET)

    # set tab completion and other comfort options
    if 'readline' in sys.modules:
        readline.parse_and_bind("tab: complete")
        readline.parse_and_bind("set editing-mode vi")

    # initialise the SMM stuff
    smm.init()
    
    # open and run a shell
    sh = code.InteractiveConsole(globals())
    sh.interact('SMM Shell')
    
    smm.deinit()

if __name__ == "__main__":
    run_shell()
